Error

Struct Error 

pub struct Error(/* private fields */);
A general error with a message and a backtrace (if enabled).

Implementations

Source

impl Error

pub fn new(message: String) -> Self

Creates a new error and captures the backtrace (if enabled).

pub fn message(&self) -> &str

Description of the error.

pub fn backtrace(&self) -> &Backtrace

Backtrace to where the error was created.